@@ -3,7 +3,7 @@ import os
 from docutils.parsers.rst import Directive, directives
 from docutils import nodes
 
-__version__ = "0.2.0"
+__version__ = "0.3.1"
 
 
 def st_static_path(app):
@@ -11,9 +11,13 @@ def st_static_path(app):
     app.config.html_static_path.append(static_path)
 
 
-def add_to_context(app, config):
+def initialize_js_assets(app, config):
     # Update the global context
-    config.html_context.update({"togglebutton_hint": config.togglebutton_hint})
+    app.add_js_file(None, body=f"let toggleHintShow = '{config.togglebutton_hint}';")
+    app.add_js_file(None, body=f"let toggleHintHide = '{config.togglebutton_hint_hide}';")
+    open_print = str(config.togglebutton_open_on_print).lower()
+    app.add_js_file(None, body=f"let toggleOpenOnPrint = '{open_print}';")
+    app.add_js_file("togglebutton.js")
 
 
 # This function reads in a variable and inserts it into JavaScript
@@ -56,11 +60,12 @@ def setup(app):
     # Tell Sphinx about this configuration variable
     app.add_config_value("togglebutton_selector", ".toggle, .admonition.dropdown", "html")
     app.add_config_value("togglebutton_hint", "Click to show", "html")
-    app.add_js_file("togglebutton.js")
+    app.add_config_value("togglebutton_hint_hide", "Click to hide", "html")
+    app.add_config_value("togglebutton_open_on_print", True, "html")
 
     # Run the function after the builder is initialized
     app.connect("builder-inited", insert_custom_selection_config)
-    app.connect("config-inited", add_to_context)
+    app.connect("config-inited", initialize_js_assets)
     app.add_directive("toggle", Toggle)
     return {
         "version": __version__,
